@@ -48,6 +48,10 @@
 #' (Taille minimale des grappes constituées pour le lissage "médian" (géographiquement pondéré). (`integer`))
 #' @param inspire (boolean) : if TRUE, returns a column for Inspire grid names.
 #' 
+#' @return 
+#' Returns an object inheriting from the `data.frame` class.
+#' (Retourne un objet qui se comporte comme un `data.frame`, par heritage.)
+#' 
 #' @details 
 #' Returns an object inheriting from the `data.frame` class. (Retourne un objet qui se comporte comme un `data.frame`, par heritage.)
 #' 
@@ -67,7 +71,7 @@
 #' 
 #' 
 #' @examples 
-#' \dontrun{
+#' \donttest{
 #' # Example 1
 #' data(dfPrix_SP95_2016)
 #' dfPrix_SP95_2016$nbObs <- 1L
@@ -153,7 +157,7 @@ btb_smooth <-
            vQuantiles = NULL ,
            dfCentroids = NULL ,
            iNeighbor = NULL,
-           inspire = F,
+           inspire = FALSE,
            iNbObsMin = 250
   )
   {
